/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 ForTISS GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.editpart;

import static org.fortiss.tooling.base.layout.DefaultLayoutConstants.DEFAULT_CONNECTOR_SIZE;
import static org.fortiss.tooling.base.ui.utils.RectangleLayoutUtils.getAbsoluteConnectorBounds;

import org.eclipse.draw2d.geometry.Rectangle;
import org.fortiss.tooling.base.model.base.EntryConnectorBase;
import org.fortiss.tooling.base.model.element.IConnector;
import org.fortiss.tooling.base.model.layout.ILayoutedModelElement;
import org.fortiss.tooling.kernel.model.INamedCommentedElement;

/**
 * Abstract implementation for sticky connector edit parts. Usually, the
 * connector sticks to some parent edit part, e.g., a connector moving only on
 * the border of its parent element when the parent is viewed externally.
 * 
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating GREEN Hash: 49F7C34AF000C6BAFEFCACF201F22DD1
 */
public abstract class StickyConnectorEditPartBase<T extends ILayoutedModelElement & IConnector & INamedCommentedElement>
		extends ConnectorEditPartBase<T> {

	/** Constructor. */
	protected StickyConnectorEditPartBase(T modelElement) {
		super(modelElement);
	}

	/** {@inheritDoc} */
	@Override
	protected Rectangle determineBaseFigureBounds() {
		if(getModel().eContainer() instanceof ILayoutedModelElement) {
			return getAbsoluteConnectorBounds(getModel(), (ILayoutedModelElement)getModel()
					.eContainer());
		}
		return new Rectangle(0, 0, DEFAULT_CONNECTOR_SIZE, DEFAULT_CONNECTOR_SIZE);
	}

	/** {@inheritDoc} */
	@Override
	protected boolean isTarget() {
		return getModel() instanceof EntryConnectorBase;
	}

	/** Returns the parent element edit part. */
	@SuppressWarnings("unchecked")
	public ElementEditPartBase<? extends ILayoutedModelElement> getParentEditPart() {
		return (ElementEditPartBase<? extends ILayoutedModelElement>)getParent();
	}
}
