/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2012 ForTISS GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.graphicsGL.ui.objects;

import java.util.ArrayList;
import java.util.List;

import org.fortiss.tooling.graphicsGL.ui.camera.Camera;
import org.fortiss.tooling.graphicsGL.ui.picker.ModelObjectPicker;

/**
 * Composite for {@link ViewObjectBase model objects} forwarding rendering and picking calls to
 * component objects.
 * 
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating GREEN Hash: 1E93056065A5E6192B46B6950EBC1B97
 */
public class CompositeViewObject extends ViewObjectBase {
	/** The component objects. */
	private final List<ViewObjectBase> objects = new ArrayList<ViewObjectBase>();

	/** {@inheritDoc} */
	@Override
	public void renderObject(Camera c) {
		for(ViewObjectBase o : objects) {
			o.renderObject(c);
		}
	}

	/** {@inheritDoc} */
	@Override
	public void renderObjectForPicking(ModelObjectPicker picker, Camera c) {
		for(ViewObjectBase o : objects) {
			o.renderObjectForPicking(picker, c);
		}
	}
}
