/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2012 ForTISS GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.graphicsGL.util;

import static org.eclipse.emf.ecore.util.EcoreUtil.copy;
import static org.fortiss.tooling.graphicsGL.util.Graphics3DModelElementFactory.vector;

import java.util.List;

import org.fortiss.tooling.graphicsGL.model.Color3D;
import org.fortiss.tooling.graphicsGL.model.graph.Axis3D;
import org.fortiss.tooling.graphicsGL.model.graph.CoordinateSystem3D;
import org.fortiss.tooling.graphicsGL.model.graph.Graph3D;
import org.fortiss.tooling.graphicsGL.model.graph.GraphFactory;
import org.fortiss.tooling.graphicsGL.model.graph.GraphLine3D;
import org.fortiss.tooling.graphicsGL.model.graph.GraphPackage;
import org.fortiss.tooling.graphicsGL.model.graph.GraphPoint3D;
import org.fortiss.tooling.graphicsGL.model.graph.GraphText3D;

/**
 * Model element factory for {@link GraphPackage}.
 * 
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating GREEN Hash: 89CE25DC16E18195D9F1D8F0D6D3D2DB
 */
public class Graph3DModelElementFactory {
	/** Creates a graph point. */
	public static GraphPoint3D graphPoint(float x, float y, float z) {
		GraphPoint3D point = GraphFactory.eINSTANCE.createGraphPoint3D();
		point.setPosition(vector(x, y, z));
		return point;
	}

	/** Creates a graph line from the given points. */
	public static GraphLine3D graphLine(GraphPoint3D start, GraphPoint3D end) {
		GraphLine3D line = GraphFactory.eINSTANCE.createGraphLine3D();
		line.setStart(start);
		line.setEnd(end);
		return line;
	}

	/** Creates an axis. */
	public static Axis3D axis(float length, Color3D color) {
		Axis3D axis = GraphFactory.eINSTANCE.createAxis3D();
		axis.setLength(length);
		axis.setColor(copy(color));
		return axis;
	}

	/** Creates the coordinate system with the given axes. */
	public static CoordinateSystem3D coordSystem(Axis3D xAxis, Axis3D yAxis, Axis3D zAxis) {
		CoordinateSystem3D sys = GraphFactory.eINSTANCE.createCoordinateSystem3D();
		sys.setXAxis(xAxis);
		sys.setYAxis(yAxis);
		sys.setZAxis(zAxis);
		return sys;
	}

	/** Creates a graph. */
	public static Graph3D graph(CoordinateSystem3D system, List<GraphPoint3D> points,
			List<GraphLine3D> lines) {
		Graph3D g = GraphFactory.eINSTANCE.createGraph3D();
		g.setCoordinateSystem(system);
		g.getPointsList().addAll(points);
		g.getLinesList().addAll(lines);
		return g;
	}

	/** Creates a text */
	public static GraphText3D text(String text, GraphPoint3D pos) {
		GraphText3D gt = GraphFactory.eINSTANCE.createGraphText3D();
		gt.setText(text);
		gt.setPosition(pos);
		return gt;
	}
}
